import { douyinCollector } from './js/douyin.js';
import { xiaohongshuCollector } from './js/xiaohongshu.js';
import { bilibiliCollector } from './js/bilibili.js';

// 检查VIP状态和使用次数的全局函数
async function checkVipAndUsage() {
  try {
    const formData = new FormData();
    formData.append('token', globalToken);
    const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.checkVipStatus}`, {
      method: 'POST',
      body: formData
    });
    const data = await response.json();

    if (!data.ok) {
      layer.msg(data.msg, { icon: 2, time: 2000 });
      return false;
    }

    if (!data.is_vip && data.analyze_count >= data.analyze_limit) {
      layer.msg(`您今日的免费使用次数已达上限(${data.analyze_limit}次),请升级VIP享受无限使用!`, {
        icon: 2,
        time: 3000
      });
      return false;
    }
    return true;
  } catch (error) {
    console.error('检查VIP状态失败:', error);
    return false;
  }
}

// 防抖函数
function debounce(func, wait = 1000) {
  let timeout;
  let isProcessing = false;
  return async function executedFunction(...args) {
    // 如果正在处理中，直接返回
    if (isProcessing) {
      layer.msg('操作进行中，请稍候...', {
        icon: 0,
        time: 1000
      });
      return;
    }

    // 检查VIP和使用次数
    if (!(await checkVipAndUsage())) {
      return;
    }

    const later = () => {
      clearTimeout(timeout);
      // 包装异步函数，确保完成后重置状态
      Promise.resolve(func(...args)).finally(() => {
        isProcessing = false;
      });
    };

    // 设置处理中状态
    isProcessing = true;
    clearTimeout(timeout);
    timeout = setTimeout(later, 100);
  };
}

// 添加 API 配置
const API_CONFIG = {
  baseUrl: 'http://aidata.phpdisk.com/', // 替换为实际的API地址
  endpoints: {
    login: 'api/chrome.php?action=login', //登录
    verifyToken: 'api/chrome.php?action=verify_token', //实时验证登录
    captcha: 'includes/imgcode.inc.php', // 添加验证码接口
    oauth: 'api/chrome.php?action=oauth', // 添加oauth接口
    analyzeKeywords: 'api/analyze_keywords.php?action=do', // 添加关键词分析端点
    checkVipStatus: 'api/chrome.php?action=check_vip_status', // 添加VIP状态检查端点
    updateUseCount: 'api/chrome.php?action=update_use_count', // 添加采集数
    checkUpdate: 'api/chrome.php?action=check_update' // 添加版本检查接口
  }
};

let globalUsername = '';
let globalToken = '';
let videoCount = 0;
let lastVersion = '1.0.1';
let lastRelease = '20250222';

// 添加AI Data官方网站链接点击事件 - 使用类选择器
document.addEventListener('DOMContentLoaded', function() {
  const aidataLinks = document.querySelectorAll('.aidata_link');
  aidataLinks.forEach(link => {
    link.addEventListener('click', function(e) {
      e.preventDefault();
      chrome.tabs.create({ url: `${API_CONFIG.baseUrl}` });
    });
  });
});

// 在文件开头添加登录验证相关代码
document.addEventListener('DOMContentLoaded', async function () {
  // 初始化验证码
  refreshCaptcha();

  // 检查更新
  await checkUpdate();

  // 点击验证码图片刷新
  document.getElementById('captchaImage').addEventListener('click', refreshCaptcha);

  // 添加注册按钮点击事件
  document.getElementById('registerBtn').addEventListener('click', function (e) {
    e.preventDefault();
    chrome.tabs.create({ url: `${API_CONFIG.baseUrl}account.php?action=register&utm_from=browser` });
  });

  // 添加回车键监听
  document.getElementById('username').addEventListener('keypress', handleEnterKey);
  document.getElementById('password').addEventListener('keypress', handleEnterKey);
  document.getElementById('captcha').addEventListener('keypress', handleEnterKey);

  // 检查登录状态
  const isLoggedIn = await checkLoginStatus();
  if (isLoggedIn) {
    await showFunctionArea();
    // 确保在二次加载时也检查VIP状态
    await checkUserVIPStatus();
    } else {
      showLoginArea();
    }
  });

// 登录状态检查函数
async function checkLoginStatus() {
  return new Promise((resolve) => {
    chrome.storage.local.get(['token', 'username'], async (result) => {
      if (result.token && result.username) {
        globalUsername = result.username;
        globalToken = result.token;
        try {
          const formData = new FormData();
          formData.append('token', result.token);

          const loadingIndex = layer.load(1, {
            shade: [1, '#fff']
          });

          const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.verifyToken}`, {
            method: 'POST',
            body: formData
          });

          const data = await response.json();
          layer.close(loadingIndex);

          if (data.ok) {
            // 更新全局变量
            globalToken = result.token;
            globalUsername = result.username;
            resolve(true);
            return;
          }
        } catch (error) {
          console.error('Token verification error:', error);
        }
        // 验证失败，清除存储的信息
        chrome.storage.local.remove(['token', 'username']);
      }
      resolve(false);
    });
  });
}

// 添加验证码刷新函数
function refreshCaptcha() {
  const captchaImage = document.getElementById('captchaImage');
  captchaImage.src = `${API_CONFIG.baseUrl}${API_CONFIG.endpoints.captcha}?t=${new Date().getTime()}`;
}

// 添加回车键提交登录功能
function handleEnterKey(event) {
  if (event.key === 'Enter') {
    document.getElementById('loginBtn').click();
  }
}

// 修改登录函数，添加验证码验证
document.getElementById('loginBtn').addEventListener('click', async function () {
  const username = document.getElementById('username').value;
  const password = document.getElementById('password').value;
  const captcha = document.getElementById('captcha').value;

  if (!username || !password || !captcha) {
    layer.msg('请填写用户名、密码及验证码', {
      icon: 0,
      time: 2000
    });
    return;
  }

  try {
    const formData = new FormData();
    formData.append('username', username);
    formData.append('password', password);
    formData.append('captcha', captcha);

    const loadingIndex = layer.load(1, {
      shade: [0.8, '#fff']
    });

    const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.login}`, {
      method: 'POST',
      body: formData
    });

    const data = await response.json();
    layer.close(loadingIndex);

    if (data.ok) {
      //alert(JSON.stringify(data.user));
      globalToken = data.token;
      globalUsername = data.user.username;
      chrome.storage.local.set({
        token: data.token,
        username: data.user.username
      }, async function () {
      layer.msg('登录成功', {
        icon: 1,
        time: 1000
      });
        await showFunctionArea(username);
        // 立即检查VIP状态
        await checkUserVIPStatus();
      });
    } else {
      // 登录失败时刷新验证码
      refreshCaptcha();
      document.getElementById('captcha').value = '';
      layer.msg(data.msg || '登录失败', {
        icon: 2,
        time: 2000
      });
    }
  } catch (error) {
    console.error('Login error:', error);
    refreshCaptcha();
    layer.msg('登录失败，请重试', {
      icon: 2,
      time: 2000
    });
  }
});

// 退出登录
document.getElementById('logout').addEventListener('click', function () {
  layer.confirm('确定要退出登录吗？', {
    btn: ['确定', '取消'],
    title: '',
    closeBtn: 0
  }, function () {
    chrome.storage.local.remove(['token', 'username'], function () {
      layer.msg('已退出登录', {
        icon: 1,
        time: 1000
      });
      showLoginArea();
    });
  });
});

// 显示功能区域
async function showFunctionArea(username) {
  const nameTxt = username || globalUsername;
  document.getElementById('loginArea').style.display = 'none';
  const functionArea = document.getElementById('functionArea');
  functionArea.style.display = 'block';
  functionArea.classList.add('fade-in');

  // 更新欢迎文本
  document.getElementById('welcomeText').innerHTML = `<a href="${API_CONFIG.baseUrl}${API_CONFIG.endpoints.oauth}&token=${globalToken}" target="_blank" title="WEB管理">欢迎您, ${nameTxt}</a><span id="vipStatus"></span>`;

  // 显示WEB管理按钮
  document.getElementById('webManage').style.display = 'inline-block';

  // 等待DOM更新
  await new Promise(resolve => setTimeout(resolve, 100));
}

// 检查用户VIP状态
async function checkUserVIPStatus() {
  try {
    const formData = new FormData();
    formData.append('token', globalToken);

    const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.checkVipStatus}`, {
      method: 'POST',
      body: formData
    });

    const data = await response.json();
    const usageInfo = document.getElementById('usageInfo');

    if (data.is_vip) {
      document.getElementById('vipStatus').innerHTML = ` <img src="images/vip.gif" title="VIP权限" >`
      usageInfo.innerHTML = `
        <div class="usage-badge vip">
          尊享VIP权限，每天使用不限次数
        </div>`;
    } else {
      document.getElementById('vipStatus').innerHTML = ` <a href="${API_CONFIG.baseUrl}${API_CONFIG.endpoints.oauth}&token=${globalToken}&reurl=vip" target="_blank" title="升级VIP会员"><img src="images/no_vip.gif" alt="升级VIP会员" ></a>`
      usageInfo.innerHTML = `
        <div class="usage-badge free" title="今日剩余次数:  ${data.analyze_limit - data.analyze_count} / 每日可用次数: ${data.analyze_limit}">
          今日剩余次数:  ${data.analyze_limit - data.analyze_count} 
        </div>
        <a href="${API_CONFIG.baseUrl}${API_CONFIG.endpoints.oauth}&token=${globalToken}&reurl=vip" target="_blank" class="upgrade-btn" title="升级本站VIP尊享优质服务">
          升级VIP会员
        </a>`;
    }
  } catch (error) {
    console.error('获取用户状态失败:', error);
  }
}

// 显示登录区域
function showLoginArea() {
  const loginArea = document.getElementById('loginArea');
  document.getElementById('functionArea').style.display = 'none';
  loginArea.style.display = 'block';
  loginArea.classList.add('fade-in');
  document.getElementById('result').textContent = '';
}

// 修改现有的功能函数，添加登录检查
async function checkLoginBeforeAction() {
  const isLoggedIn = await checkLoginStatus();
  if (!isLoggedIn) {
        layer.msg('请先登录', {
          icon: 0,
          time: 2000
        });
    showLoginArea();
    return false;
  }
  return true;
}

// URL 验证函数
async function validateUrl(platform) {
  const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });
  const url = tab.url.toLowerCase();

  switch (platform) {
    case 'douyin':
      if (!url.includes('douyin.com') || !url.includes('/user/')) {
        layer.msg('请打开【抖音用户主页】后再使用此功能', {
          icon: 2,
          time: 2000
        });
        return false;
      }
      break;
    case 'xiaohongshu':
      if (!url.includes('xiaohongshu.com') || !url.includes('/user/profile/')) {
        layer.msg('请打开【小红书用户主页】后再使用此功能', {
          icon: 2,
          time: 2000
        });
        return false;
      }
      break;
    case 'bilibili':
      if (!url.includes('space.bilibili.com')) {
        layer.msg('请打开【B站用户空间】后再使用此功能', {
          icon: 2,
          time: 2000
        });
        return false;
      }
      break;
  }
  return true;
}

// 按钮状态管理
function disableAllButtons() {
  const buttons = document.querySelectorAll('.function-buttons button');
  buttons.forEach(button => {
    button.disabled = true;
    button.style.opacity = '0.5';
    button.style.cursor = 'not-allowed';
  });
}

function enableAllButtons() {
  const buttons = document.querySelectorAll('.function-buttons button');
  buttons.forEach(button => {
    button.disabled = false;
    button.style.opacity = '1';
    button.style.cursor = 'pointer';
  });
}

// 增加使用次数的函数
async function incrementUsageCount() {
  try {
    const formData = new FormData();
    formData.append('token', globalToken);

    const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.updateUseCount}`, {
      method: 'POST',
      body: formData
    });

    const data = await response.json();
    if (!data.ok) {
      console.error('增加使用次数失败:', data.msg);
    }
  } catch (error) {
    console.error('增加使用次数失败:', error);
  }
}

// 抖音自动浏览
document.getElementById('autoScrollDouyin').addEventListener('click', debounce(async () => {
  if (!await checkLoginBeforeAction()) return;
  if (!await validateUrl('douyin')) return;
  // 检查VIP和使用次数限制
  if (!(await checkVipAndUsage())) return;

  const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });

  try {
    disableAllButtons();
    document.getElementById('result').textContent = '正在刷新页面...';
    // 先刷新页面
    await chrome.tabs.reload(tab.id);

    // 等待页面完全加载
    await new Promise((resolve) => {
      chrome.tabs.onUpdated.addListener(function listener(tabId, info) {
        if (tabId === tab.id && info.status === 'complete') {
          chrome.tabs.onUpdated.removeListener(listener);
          // 页面加载完成后再等待2秒
          setTimeout(resolve, 2000);
        }
  });
});

    document.getElementById('result').textContent = 'AI之眼正在浏览视频，请稍候...';
    const result = await douyinCollector.autoScroll(tab);

    const data = result;
    if (data.hasData) {
      videoCount = data.count;
      document.getElementById('result').textContent = `浏览完成，共找到 ${data.count} 个视频，正在导出...`;

      try {
        const content = await douyinCollector.getHTML(tab);
        // 获取原始URL
        const originalUrl = tab.url;

        window.extractedData = content.data;

        // 导出数据
  if (!window.extractedData || window.extractedData.length === 0) {
          layer.msg('未获取到内容！', {
            icon: 0,
            time: 2000
          });
    return;
  }

        const { blob, fileName } = await douyinCollector.exportToExcel(content, videoCount, tab, originalUrl);

        const url = URL.createObjectURL(blob);
  const link = document.createElement('a');
        link.setAttribute('href', url);
        link.setAttribute('download', fileName);
  document.body.appendChild(link);
  link.click();
  document.body.removeChild(link);
        URL.revokeObjectURL(url);

        // 增加使用次数
        await incrementUsageCount();

        layer.msg('导出成功', {
          icon: 1,
          time: 2000
        });
      } catch (error) {
        console.error('Export error:', error);
        layer.msg(error.message || '导出失败，请重试', {
          icon: 2,
          time: 2000
        });
      }
    } else {
      document.getElementById('result').textContent = '未找到视频数据';
    }
  } catch (error) {
    document.getElementById('result').textContent = error.message;
  } finally {
    enableAllButtons();
  }
}, 1000));

// 小红书自动浏览
document.getElementById('autoScrollXiaohongshu').addEventListener('click', debounce(async () => {
  if (!await checkLoginBeforeAction()) return;
  if (!await validateUrl('xiaohongshu')) return;
  // 检查VIP和使用次数限制
  if (!(await checkVipAndUsage())) return;

  const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });
  
  try {
    disableAllButtons();
    document.getElementById('result').textContent = '正在刷新页面...';
    // 先刷新页面
    await chrome.tabs.reload(tab.id);

    // 等待页面完全加载
    await new Promise((resolve) => {
      chrome.tabs.onUpdated.addListener(function listener(tabId, info) {
        if (tabId === tab.id && info.status === 'complete') {
          chrome.tabs.onUpdated.removeListener(listener);
          // 页面加载完成后再等待2秒
          setTimeout(resolve, 2000);
        }
      });
    });

    document.getElementById('result').textContent = 'AI之眼正在浏览视频，请稍候...';
    const result = await xiaohongshuCollector.autoScroll(tab);

    const data = result;
    if (data.hasData) {
      videoCount = data.count;
      document.getElementById('result').textContent = `浏览完成，共找到 ${data.count} 个笔记，正在导出...`;
      try {
        // 获取原始URL
        const originalUrl = tab.url;
        const { blob, fileName } = await xiaohongshuCollector.exportToExcel(data.collectedData, data.count, originalUrl);

        const url = URL.createObjectURL(blob);
        const link = document.createElement('a');
        link.setAttribute('href', url);
        link.setAttribute('download', fileName);
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
        URL.revokeObjectURL(url);

        // 增加使用次数
        await incrementUsageCount();

        layer.msg('导出成功', {
          icon: 1,
          time: 2000
        });
      } catch (error) {
        console.error('Export error:', error);
        layer.msg(error.message || '导出失败，请重试', {
          icon: 2,
          time: 2000
        });
      }
    } else {
      document.getElementById('result').textContent = '未找到笔记数据';
    }
  } catch (error) {
    document.getElementById('result').textContent = error.message;
  } finally {
    enableAllButtons();
  }
}, 1000));

// 修改关键词分析部分
document.getElementById('analyzeKeywords').addEventListener('click', debounce(async () => {
  if (!await checkLoginBeforeAction()) return;
  
  try {
    disableAllButtons();
          const input = document.createElement('input');
          input.type = 'file';
          input.accept = '.csv';
          
          input.onchange = async (e) => {
            const file = e.target.files[0];
      if (!file) return;

      // 检查文件大小
      const maxSize = 10 * 1024 * 1024; // 10MB
      if (file.size > maxSize) {
        layer.msg('文件大小不能超过10MB', {
          icon: 2,
          time: 2000
        });
        return;
      }

      // 检查文件类型
      if (!file.name.toLowerCase().endsWith('.csv')) {
        layer.msg('请选择CSV文件', {
          icon: 2,
          time: 2000
        });
        return;
      }

      const formData = new FormData();
      formData.append('file', file);
      formData.append('token', globalToken);

      const loadingIndex = layer.load(1, {
        shade: [0.8, '#fff']
      });

      try {
        const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.analyzeKeywords}`, {
          method: 'POST',
          body: formData
        });

        const result = await response.json();
        layer.close(loadingIndex);

        if (result.ok) {
          // 在新标签页中打开分析报告
          chrome.tabs.create({
            url: result.reportUrl
          });
        } else {
          throw new Error(result.msg || '分析失败');
        }
      } catch (error) {
        layer.close(loadingIndex);
        layer.msg(error.message || '分析失败，请重试', {
          icon: 2,
          time: 5000
        });
      }
    };

    input.click();
  } catch (error) {
    layer.msg('操作失败：' + error.message, {
      icon: 2,
      time: 2000
    });
  } finally {
    enableAllButtons();
  }
}, 1000));

// 添加WEB管理按钮点击事件
document.getElementById('webManage').addEventListener('click', function () {
  chrome.tabs.create({
    url: `${API_CONFIG.baseUrl}${API_CONFIG.endpoints.oauth}&token=${globalToken}`
  });
});

// B站自动浏览
document.getElementById('autoScrollBilibili').addEventListener('click', async () => {
  if (!await checkLoginBeforeAction()) return;
  if (!await validateUrl('bilibili')) return;
  // 检查VIP和使用次数限制
  if (!(await checkVipAndUsage())) return;

  const [tab] = await chrome.tabs.query({ active: true, currentWindow: true });

  try {
    document.getElementById('result').textContent = '正在刷新页面...';
    // 先刷新页面
    await chrome.tabs.reload(tab.id);

    // 等待页面完全加载
    await new Promise((resolve) => {
      chrome.tabs.onUpdated.addListener(function listener(tabId, info) {
        if (tabId === tab.id && info.status === 'complete') {
          chrome.tabs.onUpdated.removeListener(listener);
          // 页面加载完成后再等待2秒
          setTimeout(resolve, 2000);
        }
      });
    });

    document.getElementById('result').textContent = 'AI之眼正在浏览视频，请稍候...';
    const result = await bilibiliCollector.autoScroll(tab);

    if (result.hasData) {
      videoCount = result.count;
      document.getElementById('result').textContent = `浏览完成，共找到 ${result.count} 个视频，正在导出...`;
      try {
        // 获取原始URL
        const originalUrl = tab.url;
        const { blob, fileName } = await bilibiliCollector.exportToExcel(result.collectedData, result.count, originalUrl);

        const url = URL.createObjectURL(blob);
        const link = document.createElement('a');
        link.setAttribute('href', url);
        link.setAttribute('download', fileName);
        document.body.appendChild(link);
        link.click();
        document.body.removeChild(link);
        URL.revokeObjectURL(url);

        // 增加使用次数
        await incrementUsageCount();

        layer.msg('导出成功', {
          icon: 1,
          time: 2000
        });
      } catch (error) {
        console.error('Export error:', error);
        layer.msg(error.message || '导出失败，请重试', {
          icon: 2,
          time: 2000
        });
      }
    } else {
      document.getElementById('result').textContent = '未找到视频数据';
    }
  } catch (error) {
    document.getElementById('result').textContent = error.message;
  }
});

// 检查插件版本更新函数
async function checkUpdate() {
  try {
    // 获取存储的更新设置
    const updateSettings = await new Promise((resolve, reject) => {
      try {
        chrome.storage.local.get(['skipUpdateUntil', 'skipVersion'], (result) => {
          if (chrome.runtime.lastError) {
            reject(chrome.runtime.lastError);
          } else {
            resolve(result);
          }
        });
      } catch (error) {
        reject(error);
      }
    });

    // 检查是否在免打扰期内
    const now = new Date().getTime();
    if (updateSettings.skipUpdateUntil &&
      now < parseInt(updateSettings.skipUpdateUntil) &&
      updateSettings.skipVersion === lastVersion) {
      console.log('在免打扰期内，跳过更新检查');
      return;
    }

    const formData = new FormData();
    formData.append('version', lastVersion);
    formData.append('release', lastRelease);

    const response = await fetch(`${API_CONFIG.baseUrl}${API_CONFIG.endpoints.checkUpdate}`, {
      method: 'POST',
      body: formData
    });

    const data = await response.json();
    if (data.hasUpdate) {
      const index = layer.confirm(`发现新版本: ${data.version}<br>更新内容：${data.description}`, {
        btn: ['立即更新', '稍后提醒', '暂不升级'],
        title: '版本更新提示',
        closeBtn: 0
      }, function (index) { // 点击"立即更新"
        layer.close(index);
        chrome.tabs.create({ url: data.downloadUrl });
      }, function (index) { // 点击"稍后提醒"
        layer.close(index);
      });

      // 监听"暂不升级"按钮点击
      $('.layui-layer-btn2').click(function () {
        // 设置7天内不再提示
        const settings = {
          skipUpdateUntil: now + (7 * 24 * 60 * 60 * 1000),
          skipVersion: lastVersion
        };

        chrome.storage.local.set(settings, () => {
          if (chrome.runtime.lastError) {
            console.error('保存更新设置失败:', chrome.runtime.lastError);
            layer.msg('设置失败，请重试', {
              icon: 2,
              time: 2000
            });
          } else {
            layer.msg('已设置暂不升级', {
              icon: 1,
              time: 2000
            });
          }
        });

        layer.close(index);
      });
    }
  } catch (error) {
    console.error('检查更新失败:', error);
  }
}

// 添加链接点击事件 - 使用新标签页打开
document.addEventListener('DOMContentLoaded', function() {
  const links = document.querySelectorAll('a[target="_blank"]');
  links.forEach(link => {
    link.addEventListener('click', function(e) {
      e.preventDefault();
      chrome.tabs.create({
        url: this.href
      });
    });
  });
});



